@@ -1,5 +1,8 @@
+from functools import partial
 from importlib import import_module, reload
 import asyncio
+
+from click import Context
 from arkitekt_next import App
 from watchfiles import awatch, Change
 from rich.panel import Panel
@@ -9,16 +12,15 @@ import os
 import sys
 import inspect
 from rekuest_next.definition.registry import get_default_definition_registry
-from rekuest_next.agents.hooks import get_default_hook_registry
+from rekuest_next.agents.hooks.registry import get_default_hook_registry
 from typing import MutableSet, Tuple, Any, Set
 from arkitekt_next.cli.ui import construct_changes_group, construct_app_group
 from arkitekt_next.cli.commands.run.utils import import_builder
 from arkitekt_next.cli.types import Manifest
-from arkitekt_next.apps.types import App
+from arkitekt_next.app.app import App
 import rich_click as click
-import os
 from arkitekt_next.cli.options import (
-    with_fakts_url,
+    with_fakts_next_url,
     with_builder,
     with_token,
     with_instance_id,
@@ -105,7 +107,7 @@ async def run_app(app: App) -> None:
         raise Exception("No rekuest service found. We need this to run the app.")
 
     async with app:
-        await rekuest.run()
+        await rekuest.arun()
 
 
 def reload_modules(reloadable_modules) -> None:
@@ -166,10 +168,30 @@ def is_entrypoint_change(
     return False
 
 
+def callback(console: Console, future: asyncio.Task[None]):
+    if future.cancelled():
+        return
+    else:
+        has_exception = future.exception()
+
+        if not has_exception:
+            panel = Panel(
+                "App finished running", style="bold yellow", border_style="yellow"
+            )
+            console.print(panel)
+        else:
+            try:
+                raise has_exception
+            except Exception:
+                console.print_exception()
+                panel = Panel("Error running App", style="bold red", border_style="red")
+                console.print(panel)
+
+
 async def run_dev(
     console: Console,
     manifest: Manifest,
-    version=None,
+    version: str | None = None,
     builder: str = "arkitekt_next.builders.easy",
     deep: bool = False,
     **builder_kwargs,
@@ -210,26 +232,8 @@ async def run_dev(
         console.print(panel)
         module = None
 
-    def callback(future):
-        if future.cancelled():
-            return
-        else:
-            has_exception = future.exception()
-
-            if not has_exception:
-                panel = Panel(
-                    "App finished running", style="bold yellow", border_style="yellow"
-                )
-                console.print(panel)
-            else:
-                try:
-                    raise has_exception
-                except Exception:
-                    console.print_exception()
-                    panel = Panel(
-                        "Error running App", style="bold red", border_style="red"
-                    )
-                    console.print(panel)
+    current_run: asyncio.Future[None] | None = None
+    # This is the main task that is running the app
 
     try:
         app: App = builder_func(
@@ -242,8 +246,8 @@ async def run_dev(
         panel = Panel(group, style="bold green", border_style="green")
         console.print(panel)
 
-        x = asyncio.create_task(run_app(app))
-        x.add_done_callback(callback)
+        current_run = asyncio.create_task(run_app(app))
+        current_run.add_done_callback(partial(callback, console))
     except Exception:
         console.print_exception()
         panel = Panel(
@@ -258,9 +262,12 @@ async def run_dev(
         step=500,
     ):
         if deep:
+            #
             to_be_reloaded = check_deeps(changes)
             if not to_be_reloaded:
                 continue
+        else:
+            to_be_reloaded: Set[str] = set()
 
         group = construct_changes_group(changes)
         panel = Panel(group, style="bold blue", border_style="blue")
@@ -268,17 +275,17 @@ async def run_dev(
 
         console.print(panel)
         # Cancelling the app
-        if not x or x.done():
+        if not current_run or current_run.done():
             pass
 
         else:
-            x.cancel()
+            current_run.cancel()
             panel = Panel(
                 "Cancelling latest version", style="bold yellow", border_style="yellow"
             )
             console.print(panel)
             try:
-                await x
+                await current_run
 
             except asyncio.CancelledError:
                 pass
@@ -316,8 +323,8 @@ async def run_dev(
             panel = Panel(group, style="bold green", border_style="green")
             console.print(panel)
 
-            x = asyncio.create_task(run_app(app))
-            x.add_done_callback(callback)
+            current_run = asyncio.create_task(run_app(app))
+            current_run.add_done_callback(partial(callback, console))
         except Exception:
             console.print_exception()
             panel = Panel(
@@ -327,7 +334,7 @@ async def run_dev(
 
 
 @click.command()
-@with_fakts_url
+@with_fakts_next_url
 @with_builder
 @with_token
 @with_instance_id
@@ -341,7 +348,7 @@ async def run_dev(
     is_flag=True,
 )
 @click.pass_context
-def dev(ctx, **kwargs):
+def dev(ctx: Context, **kwargs):
     """Runs the app in dev mode (with hot reloading)
 
     Running the app in dev mode will automatically reload the app when changes are detected.
