@@ -1,9 +1,12 @@
+""" An example of a simple template for Arkitekt Next"""
+
 from arkitekt_next import register
 import time
+from typing import Generator
 
 
 @register
-def generate_n_string(n: int = 10, timeout: int = 2) -> str:
+def generate_n_string(n: int = 10, timeout: int = 2) -> Generator[str, None, None]:
     """Generate N Strings
 
     This function generates {{n}} strings with a {{timeout}} ms timeout between each string
